@@ -7,21 +7,6 @@
    Check these declarations against the C/Fortran source code.
 */
 
-/* .C calls */
-
-extern void rjd2c(void *, void *, void *, void *, void *);
-
-
-
-static const R_CMethodDef CEntries[] = {
-
-    {"rjd2c", (DL_FUNC) &rjd2c, 5},
-
-    {NULL, NULL, 0}
-
-};
-
-
 
 /* .Call calls */
 extern SEXP CCK(SEXP, SEXP);
@@ -33,6 +18,8 @@ extern SEXP TSAVE(SEXP, SEXP, SEXP, SEXP);
 extern SEXP TSIR(SEXP, SEXP, SEXP, SEXP);
 extern SEXP lblinM(SEXP, SEXP);
 extern SEXP lbsqM(SEXP, SEXP);
+extern SEXP EIGEN(SEXP);
+extern SEXP PREPBSS(SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
     {"CCK",    (DL_FUNC) &CCK,    2},
@@ -44,6 +31,8 @@ static const R_CallMethodDef CallEntries[] = {
     {"TSIR",   (DL_FUNC) &TSIR,   4},
     {"lblinM", (DL_FUNC) &lblinM, 2},
     {"lbsqM",  (DL_FUNC) &lbsqM,  2},
+    {"EIGEN",  (DL_FUNC) &EIGEN,  1},
+    {"PREPBSS",  (DL_FUNC) &PREPBSS,  2},
     {NULL, NULL, 0}
 };
 
@@ -51,6 +40,6 @@ static const R_CallMethodDef CallEntries[] = {
 
 void R_init_tsBSS(DllInfo *dll)
 {
-    R_registerRoutines(dll, CEntries, CallEntries, NULL, NULL);
+    R_registerRoutines(dll, NULL, CallEntries, NULL, NULL);
     R_useDynamicSymbols(dll, FALSE);
 }
